@import 'theme.css';

.rst-content .note .admonition-title, .rst-content .note .wy-alert-title, .rst-content .seealso .admonition-title, .rst-content .seealso .wy-alert-title, .rst-content .wy-alert-info.admonition-todo .admonition-title, .rst-content .wy-alert-info.admonition-todo .wy-alert-title, .rst-content .wy-alert-info.admonition .admonition-title, .rst-content .wy-alert-info.admonition .wy-alert-title, .rst-content .wy-alert-info.attention .admonition-title, .rst-content .wy-alert-info.attention .wy-alert-title, .rst-content .wy-alert-info.caution .admonition-title, .rst-content .wy-alert-info.caution .wy-alert-title, .rst-content .wy-alert-info.danger .admonition-title, .rst-content .wy-alert-info.danger .wy-alert-title, .rst-content .wy-alert-info.error .admonition-title, .rst-content .wy-alert-info.error .wy-alert-title, .rst-content .wy-alert-info.hint .admonition-title, .rst-content .wy-alert-info.hint .wy-alert-title, .rst-content .wy-alert-info.important .admonition-title, .rst-content .wy-alert-info.important .wy-alert-title, .rst-content .wy-alert-info.tip .admonition-title, .rst-content .wy-alert-info.tip .wy-alert-title, .rst-content .wy-alert-info.warning .admonition-title, .rst-content .wy-alert-info.warning .wy-alert-title, .rst-content .wy-alert.wy-alert-info .admonition-title, .wy-alert.wy-alert-info .rst-content .admonition-title, .wy-alert.wy-alert-info .wy-alert-title {
    background: #ff944d;
}

.rst-content .note, .rst-content .seealso, .rst-content .wy-alert-info.admonition, .rst-content .wy-alert-info.admonition-todo, .rst-content .wy-alert-info.attention, .rst-content .wy-alert-info.caution, .rst-content .wy-alert-info.danger, .rst-content .wy-alert-info.error, .rst-content .wy-alert-info.hint, .rst-content .wy-alert-info.important, .rst-content .wy-alert-info.tip, .rst-content .wy-alert-info.warning, .wy-alert.wy-alert-info {
    background: #e7f7f9;
}

.rst-content .wy-alert-neutral.admonition-todo a,.rst-content .wy-alert-neutral.admonition a,.rst-content .wy-alert-neutral.attention a,.rst-content .wy-alert-neutral.caution a,.rst-content .wy-alert-neutral.danger a,.rst-content .wy-alert-neutral.error a,.rst-content .wy-alert-neutral.hint a,.rst-content .wy-alert-neutral.important a,.rst-content .wy-alert-neutral.note a,.rst-content .wy-alert-neutral.seealso a,.rst-content .wy-alert-neutral.tip a,.rst-content .wy-alert-neutral.warning a,.wy-alert.wy-alert-neutral a{
    color:#ff6600
}

.wy-tray-container li.wy-tray-item-info{
    background:#ff6600
}

.btn-info{
    background-color:#ff6600!important
}

.btn-info:hover{
    background-color:#e65c00!important
}

.btn-link{
    color:#ff6600;
}

.wy-dropdown-menu>dd>a:hover{
    background:#ff6600;
}

.wy-dropdown.wy-dropdown-bubble .wy-dropdown-menu a:hover{
    background:#ff6600;
}

.wy-inline-validate.wy-inline-validate-info .wy-input-context{
    color:#ff6600
}

a{
    color:#ff6600;
}

.wy-text-info{
    color:#ff6600!important
}

.wy-menu-vertical a:active{
    background-color:#ff6600;
}

.wy-side-nav-search{
    background-color:#fdf9ea;
}

.wy-side-nav-search img{
    background-color:#ff6600;
}

.wy-side-nav-search > div.version {
    color: hsla(0, 0%, 100%, 0.7);
}

.wy-nav .wy-menu-vertical header{
    color:#ff6600
}

.wy-menu-vertical header, .wy-menu-vertical p.caption {
    color: #e65c00;
}

.wy-nav .wy-menu-vertical a:hover{
    background-color:#ff6600;
}

.wy-nav-side {
    background: #293133;
}

.wy-nav-top{
    background:#ff6600;
}

.wy-nav-top img{
    background-color:#ff6600;
}

.rst-versions a{
    color:#ff6600;
}

.rst-content a code,.rst-content a tt{
    color:#ff6600
}

html.writer-html4 .rst-content dl:not(.docutils)>dt,html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.citation):not(.glossary):not(.simple)>dt{
    color:#ff6600;
}

html.writer-html4 .rst-content dl:not(.docutils) > dt, html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.citation):not(.glossary):not(.simple) > dt {
    background: #e7f7f9;
    border-top: 3px solid #ff944d;
}

